@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2018 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2019 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -17,7 +17,7 @@
 
 #include "filteractiondeletetest.h"
 #include "../filteractions/filteractiondelete.h"
-#include <qtest.h>
+#include <QTest>
 #include <QLabel>
 FilterActionDeleteTest::FilterActionDeleteTest(QObject *parent)
     : QObject(parent)
@@ -65,7 +65,7 @@ void FilterActionDeleteTest::shouldDeleteItem()
     item.setPayload<KMime::Message::Ptr>(msgPtr);
     MailCommon::ItemContext context(item, false);
 
-    filter.argsFromString("");
+    filter.argsFromString(QString());
     QCOMPARE(filter.process(context, false), MailCommon::FilterAction::GoOn);
     QCOMPARE(context.needsPayloadStore(), false);
     QCOMPARE(context.deleteItem(), true);
