@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2019 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -17,9 +17,9 @@
 
 #include "filteractionsetstatustest.h"
 #include "../filteractions/filteractionsetstatus.h"
-#include <qtest.h>
+#include <QTest>
 #include <QWidget>
-#include <pimcommon/minimumcombobox.h>
+#include <QComboBox>
 
 FilterActionSetStatusTest::FilterActionSetStatusTest(QObject *parent)
     : QObject(parent)
@@ -35,7 +35,7 @@ void FilterActionSetStatusTest::shouldHaveDefaultValue()
     MailCommon::FilterActionSetStatus filter;
     QWidget *w = filter.createParamWidget(nullptr);
     QCOMPARE(w->objectName(), QStringLiteral("combobox"));
-    PimCommon::MinimumComboBox *comboBox = dynamic_cast<PimCommon::MinimumComboBox *>(w);
+    auto comboBox = dynamic_cast<QComboBox *>(w);
     QVERIFY(comboBox);
     QVERIFY(!comboBox->isEditable());
     QVERIFY(comboBox->count() > 0);
