@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2019 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -17,7 +17,7 @@
 
 #include "invalidfilterinfowidgettest.h"
 #include "../invalidfilters/invalidfilterinfowidget.h"
-#include <qtest.h>
+#include <QTest>
 
 InvalidFilterInfoWidgetTest::InvalidFilterInfoWidgetTest(QObject *parent)
     : QObject(parent)
