@@ -1,9 +1,10 @@
 /*
-  Copyright (c) 2013-2018 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013-2019 Montel Laurent <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
+  This program is free software; you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 2 of the License, or
+  (at your option) any later version.
 
   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -19,6 +20,7 @@
 #include "kpimtextedit/plaintexteditor.h"
 #include "kpimtextedit/plaintexteditorwidget.h"
 #include <PimCommon/PimUtil>
+#include "filterconverttosievepurposemenuwidget.h"
 
 #include <KLocalizedString>
 #include <KSyntaxHighlighting/Definition>
@@ -60,6 +62,13 @@ FilterConvertToSieveResultDialog::FilterConvertToSieveResultDialog(QWidget *pare
     topLayout->addWidget(mEditor);
     topLayout->addWidget(buttonBox);
 
+    FilterconverttosievePurposeMenuWidget *purposeMenu = new FilterconverttosievePurposeMenuWidget(this, this);
+    QPushButton *shareButton = new QPushButton(i18n("Share..."), this);
+    shareButton->setMenu(purposeMenu->menu());
+    shareButton->setIcon(QIcon::fromTheme(QStringLiteral("document-share")));
+    purposeMenu->setEditorWidget(mEditor->editor());
+    buttonBox->addButton(shareButton, QDialogButtonBox::ActionRole);
+
     readConfig();
 }
 
