@@ -1,9 +1,10 @@
 /*
-  Copyright (c) 2012-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2012-2019 Montel Laurent <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
+  This program is free software; you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 2 of the License, or
+  (at your option) any later version.
 
   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -58,13 +59,11 @@ QString FilterImporterEvolution::defaultFiltersSettingsPath()
     return QStringLiteral("%1/.config/evolution/mail/filters.xml").arg(QDir::homePath());
 }
 
-void FilterImporterEvolution::parsePartAction(const QDomElement &ruleFilter,
-        MailCommon::MailFilter *filter,
-        parseType type)
+void FilterImporterEvolution::parsePartAction(const QDomElement &ruleFilter, MailCommon::MailFilter *filter, parseType type)
 {
     for (QDomElement partFilter = ruleFilter.firstChildElement();
-            !partFilter.isNull();
-            partFilter = partFilter.nextSiblingElement()) {
+         !partFilter.isNull();
+         partFilter = partFilter.nextSiblingElement()) {
         const QString nexttag = partFilter.tagName();
         if (nexttag == QLatin1String("part")) {
             if (partFilter.hasAttribute(QStringLiteral("name"))) {
@@ -134,16 +133,14 @@ void FilterImporterEvolution::parsePartAction(const QDomElement &ruleFilter,
                     SearchRule::Function functionName = SearchRule::FuncNone;
 
                     for (QDomElement valueFilter = partFilter.firstChildElement();
-                            !valueFilter.isNull();
-                            valueFilter = valueFilter.nextSiblingElement()) {
+                         !valueFilter.isNull();
+                         valueFilter = valueFilter.nextSiblingElement()) {
                         const QString valueTag = valueFilter.tagName();
 
                         if (valueTag == QLatin1String("value")) {
-
                             if (valueFilter.hasAttribute(QStringLiteral("name"))) {
                                 const QString name = valueFilter.attribute(QStringLiteral("name"));
                                 if (name == QLatin1String("flag")) {
-
                                     const QString flag = valueFilter.attribute(QStringLiteral("value"));
                                     qCDebug(MAILCOMMON_LOG) << " flag :" << flag;
                                     if (flag == QLatin1String("Seen")) {
@@ -190,7 +187,6 @@ void FilterImporterEvolution::parsePartAction(const QDomElement &ruleFilter,
                                 } else {
                                     qCDebug(MAILCOMMON_LOG) << " type not implemented " << name;
                                 }
-
                             }
                             if (valueFilter.hasAttribute(QStringLiteral("value"))) {
                                 const QString value = valueFilter.attribute(QStringLiteral("value"));
@@ -233,7 +229,6 @@ void FilterImporterEvolution::parsePartAction(const QDomElement &ruleFilter,
                     }
                     SearchRule::Ptr rule = SearchRule::createInstance(fieldName, functionName, contents);
                     filter->pattern()->append(rule);
-
                 } else if (type == FilterImporterEvolution::ActionType) {
                     QString actionName;
                     if (name == QLatin1String("stop")) {
@@ -271,8 +266,8 @@ void FilterImporterEvolution::parsePartAction(const QDomElement &ruleFilter,
                     }
                     QString value;
                     for (QDomElement valueFilter = partFilter.firstChildElement();
-                            !valueFilter.isNull();
-                            valueFilter = valueFilter.nextSiblingElement()) {
+                         !valueFilter.isNull();
+                         valueFilter = valueFilter.nextSiblingElement()) {
                         const QString valueTag = valueFilter.tagName();
                         if (valueTag == QLatin1String("value")) {
                             if (valueFilter.hasAttribute(QStringLiteral("name"))) {
@@ -299,7 +294,6 @@ void FilterImporterEvolution::parsePartAction(const QDomElement &ruleFilter,
                                 } else if (name == QLatin1String("address")) {
                                     //TODO
                                 }
-
                             }
                             if (valueFilter.hasAttribute(QStringLiteral("value"))) {
                                 const QString name = valueFilter.attribute(QStringLiteral("value"));
@@ -336,7 +330,6 @@ void FilterImporterEvolution::parseFilters(const QDomElement &e)
         } else {
             qCDebug(MAILCOMMON_LOG) << " grouping not implemented: " << attr;
         }
-
     }
 
     if (e.hasAttribute(QStringLiteral("source"))) {
@@ -351,8 +344,8 @@ void FilterImporterEvolution::parseFilters(const QDomElement &e)
         }
     }
     for (QDomElement ruleFilter = e.firstChildElement();
-            !ruleFilter.isNull();
-            ruleFilter = ruleFilter.nextSiblingElement()) {
+         !ruleFilter.isNull();
+         ruleFilter = ruleFilter.nextSiblingElement()) {
         const QString nexttag = ruleFilter.tagName();
         if (nexttag == QLatin1String("title")) {
             filter->pattern()->setName(ruleFilter.text());
