@@ -1,9 +1,10 @@
 /*
-  Copyright (c) 2015-2018 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2019 Montel Laurent <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
+  This program is free software; you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 2 of the License, or
+  (at your option) any later version.
 
   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -19,7 +20,7 @@
 #define INVALIDFILTERLISTMODEL_H
 
 #include <QAbstractListModel>
-#include <QList>
+#include <QVector>
 #include "invalidfilterinfo.h"
 namespace MailCommon {
 class InvalidFilterListModel : public QAbstractListModel
@@ -40,7 +41,7 @@ public:
     Q_REQUIRED_RESULT int rowCount(const QModelIndex &parent = QModelIndex()) const override;
 
 private:
-    QList<MailCommon::InvalidFilterInfo> mInvalidFilterItems;
+    QVector<MailCommon::InvalidFilterInfo> mInvalidFilterItems;
 };
 }
 
