@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2019 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -19,10 +19,10 @@
 #include "filter/filterimporterexporter.h"
 #include "filter/mailfilter.h"
 
-#include <qapplication.h>
+#include <QApplication>
 #include <QVBoxLayout>
 #include <QMenu>
-#include <qmenubar.h>
+#include <QMenuBar>
 #include <QTextEdit>
 
 Q_DECLARE_METATYPE(MailCommon::FilterImporterExporter::FilterType)
@@ -90,7 +90,7 @@ void FilterImporterExporterGui::importFilters(MailCommon::FilterImporterExporter
 {
     MailCommon::FilterImporterExporter importer(this);
     bool canceled = false;
-    const QList<MailCommon::MailFilter *> filters = importer.importFilters(canceled, type);
+    const QVector<MailCommon::MailFilter *> filters = importer.importFilters(canceled, type);
     if (canceled) {
         mTextEdit->setText(QStringLiteral("Canceled"));
         return;
