@@ -1,10 +1,11 @@
 /*
 
-  Copyright (c) 2009-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2009-2019 Montel Laurent <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
+  This program is free software; you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 2 of the License, or
+  (at your option) any later version.
 
   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -42,12 +43,12 @@ class MAILCOMMON_EXPORT EntityCollectionOrderProxyModel : public Akonadi::Entity
 public:
     explicit EntityCollectionOrderProxyModel(QObject *parent = nullptr);
 
-    virtual ~EntityCollectionOrderProxyModel();
+    ~EntityCollectionOrderProxyModel() override;
 
-    bool lessThan(const QModelIndex &left, const QModelIndex &right) const override;
+    Q_REQUIRED_RESULT bool lessThan(const QModelIndex &left, const QModelIndex &right) const override;
 
     void setManualSortingActive(bool active);
-    bool isManualSortingActive() const;
+    Q_REQUIRED_RESULT bool isManualSortingActive() const;
 
     void clearRanks();
     void setTopLevelOrder(const QStringList &list);
