@@ -1,10 +1,11 @@
 /*
 
-  Copyright (c) 2009-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2009-2019 Montel Laurent <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
+  This program is free software; you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 2 of the License, or
+  (at your option) any later version.
 
   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -45,11 +46,6 @@ class Q_DECL_HIDDEN FolderSelectionDialog::FolderSelectionDialogPrivate
 {
 public:
     FolderSelectionDialogPrivate()
-        : folderTreeWidget(nullptr)
-        , mUser1Button(nullptr)
-        , mOkButton(nullptr)
-        , mNotAllowToCreateNewFolder(false)
-        , mUseGlobalSettings(true)
     {
     }
 
@@ -57,7 +53,7 @@ public:
     QPushButton *mUser1Button = nullptr;
     QPushButton *mOkButton = nullptr;
     bool mNotAllowToCreateNewFolder = false;
-    bool mUseGlobalSettings = false;
+    bool mUseGlobalSettings = true;
 };
 
 FolderSelectionDialog::FolderSelectionDialog(QWidget *parent, SelectionFolderOptions options)
