@@ -1,10 +1,11 @@
 /*
 
-  Copyright (c) 2009-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2009-2019 Montel Laurent <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
+  This program is free software; you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 2 of the License, or
+  (at your option) any later version.
 
   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -37,16 +38,12 @@ using namespace MailCommon;
 
 FolderTreeView::FolderTreeView(QWidget *parent, bool showUnreadCount)
     : Akonadi::EntityTreeView(parent)
-    , mbDisableContextMenuAndExtraColumn(false)
-    , mbDisableSaveConfig(false)
 {
     init(showUnreadCount);
 }
 
 FolderTreeView::FolderTreeView(KXMLGUIClient *xmlGuiClient, QWidget *parent, bool showUnreadCount)
     : Akonadi::EntityTreeView(xmlGuiClient, parent)
-    , mbDisableContextMenuAndExtraColumn(false)
-    , mbDisableSaveConfig(false)
 {
     init(showUnreadCount);
 }
@@ -125,8 +122,8 @@ void FolderTreeView::readConfig()
     setIconSize(QSize(iIconSize, iIconSize));
     mToolTipDisplayPolicy
         = static_cast<FolderTreeWidget::ToolTipDisplayPolicy>(
-        myGroup.readEntry("ToolTipDisplayPolicy",
-                          static_cast<int>(FolderTreeWidget::DisplayAlways)));
+              myGroup.readEntry("ToolTipDisplayPolicy",
+                                static_cast<int>(FolderTreeWidget::DisplayAlways)));
 
     Q_EMIT changeTooltipsPolicy(mToolTipDisplayPolicy);
 
@@ -145,14 +142,16 @@ void FolderTreeView::slotHeaderContextMenuRequested(const QPoint &pnt)
     // the menu for the columns
     QMenu menu;
     QAction *act = nullptr;
-    menu.addSection(i18n("View Columns"));
     const int nbColumn = header()->count();
-    for (int i = 1; i < nbColumn; ++i) {
-        act = menu.addAction(model()->headerData(i, Qt::Horizontal).toString());
-        act->setCheckable(true);
-        act->setChecked(!header()->isSectionHidden(i));
-        act->setData(QVariant(i));
-        connect(act, &QAction::triggered, this, &FolderTreeView::slotHeaderContextMenuChangeHeader);
+    if (nbColumn > 1) {
+        menu.addSection(i18n("View Columns"));
+        for (int i = 1; i < nbColumn; ++i) {
+            act = menu.addAction(model()->headerData(i, Qt::Horizontal).toString());
+            act->setCheckable(true);
+            act->setChecked(!header()->isSectionHidden(i));
+            act->setData(QVariant(i));
+            connect(act, &QAction::triggered, this, &FolderTreeView::slotHeaderContextMenuChangeHeader);
+        }
     }
 
     menu.addSection(i18n("Icon Size"));
@@ -160,15 +159,14 @@ void FolderTreeView::slotHeaderContextMenuRequested(const QPoint &pnt)
     static const int icon_sizes[] = { 16, 22, 32};
 
     QActionGroup *grp = new QActionGroup(&menu);
-    const int nbElement((int)(sizeof(icon_sizes) / sizeof(int)));
-    for (int i = 0; i < nbElement; ++i) {
-        act = menu.addAction(QStringLiteral("%1x%2").arg(icon_sizes[ i ]).arg(icon_sizes[ i ]));
+    for (int i : icon_sizes) {
+        act = menu.addAction(QStringLiteral("%1x%2").arg(i).arg(i));
         act->setCheckable(true);
         grp->addAction(act);
-        if (iconSize().width() == icon_sizes[ i ]) {
+        if (iconSize().width() == i) {
             act->setChecked(true);
         }
-        act->setData(QVariant(icon_sizes[ i ]));
+        act->setData(QVariant(i));
 
         connect(act, &QAction::triggered, this, &FolderTreeView::slotHeaderContextMenuChangeIconSize);
     }
@@ -394,7 +392,7 @@ void FolderTreeView::slotFocusPrevFolder()
 
 void FolderTreeView::slotFocusFirstFolder()
 {
-    const QModelIndex first = moveCursor(QAbstractItemView::MoveHome, nullptr);
+    const QModelIndex first = moveCursor(QAbstractItemView::MoveHome, Qt::NoModifier);
     if (first.isValid()) {
         setCurrentModelIndex(first);
     }
@@ -402,7 +400,7 @@ void FolderTreeView::slotFocusFirstFolder()
 
 void FolderTreeView::slotFocusLastFolder()
 {
-    const QModelIndex last = moveCursor(QAbstractItemView::MoveEnd, nullptr);
+    const QModelIndex last = moveCursor(QAbstractItemView::MoveEnd, Qt::NoModifier);
     if (last.isValid()) {
         setCurrentModelIndex(last);
     }
@@ -498,12 +496,12 @@ bool FolderTreeView::allowedToEnterFolder(const Akonadi::Collection &collection,
     // parameter (kept in the config file for kmail)
     const int result
         = KMessageBox::questionYesNo(
-        const_cast<FolderTreeView *>(this),
-        i18n("<qt>Go to the next unread message in folder <b>%1</b>?</qt>", collection.name()),
-        i18n("Go to Next Unread Message"),
-        KGuiItem(i18n("Go To")),
-        KGuiItem(i18n("Do Not Go To")),         // defaults
-        QStringLiteral(":kmail_AskNextFolder"), nullptr);
+              const_cast<FolderTreeView *>(this),
+              i18n("<qt>Go to the next unread message in folder <b>%1</b>?</qt>", collection.name()),
+              i18n("Go to Next Unread Message"),
+              KGuiItem(i18n("Go To")),
+              KGuiItem(i18n("Do Not Go To")),   // defaults
+              QStringLiteral(":kmail_AskNextFolder"), KMessageBox::Option());
 
     return result == KMessageBox::Yes;
 }
@@ -520,7 +518,7 @@ bool FolderTreeView::isUnreadFolder(const QModelIndex &current, QModelIndex &ind
         if (index.isValid()) {
             const Akonadi::Collection collection
                 = index.model()->data(
-                current, Akonadi::EntityTreeModel::CollectionRole).value<Akonadi::Collection>();
+                      current, Akonadi::EntityTreeModel::CollectionRole).value<Akonadi::Collection>();
 
             if (collection.isValid()) {
                 if (collection.statistics().unreadCount() > 0) {
@@ -550,7 +548,7 @@ bool FolderTreeView::isUnreadFolder(const QModelIndex &current, QModelIndex &ind
                                 KGuiItem(i18n("Go To")),
                                 KGuiItem(i18n("Do Not Go To")),         // defaults
                                 QStringLiteral(":kmail_AskNextFolder"),
-                                nullptr) == KMessageBox::No) {
+                                KMessageBox::Option()) == KMessageBox::No) {
                             return true; // assume selected (do not continue looping)
                         }
 
@@ -570,8 +568,8 @@ Akonadi::Collection FolderTreeView::currentFolder() const
     if (current.isValid()) {
         const Akonadi::Collection collection
             = current.model()->data(
-            current,
-            Akonadi::EntityTreeModel::CollectionRole).value<Akonadi::Collection>();
+                  current,
+                  Akonadi::EntityTreeModel::CollectionRole).value<Akonadi::Collection>();
         return collection;
     }
     return Akonadi::Collection();
