@@ -1,6 +1,6 @@
 /*
 
-  Copyright (c) 2009-2018 Montel Laurent <montel@kde.org>
+  Copyright (c) 2009-2019 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -33,7 +33,6 @@
 #include <AkonadiCore/EntityMimeTypeFilterModel>
 #include <AkonadiCore/EntityTreeModel>
 #include <AkonadiCore/ItemFetchScope>
-#include <AkonadiCore/QuotaColorProxyModel>
 #include <AkonadiCore/StatisticsProxyModel>
 
 #include <AkonadiWidgets/EntityTreeView>
@@ -64,7 +63,6 @@ public:
     QString oldFilterStr;
     Akonadi::StatisticsProxyModel *filterModel = nullptr;
     FolderTreeView *folderTreeView = nullptr;
-    Akonadi::QuotaColorProxyModel *quotaModel = nullptr;
     FolderTreeWidgetProxyModel *readableproxy = nullptr;
     EntityCollectionOrderProxyModel *entityOrderProxy = nullptr;
     QLineEdit *filterFolderLineEdit = nullptr;
@@ -88,7 +86,7 @@ FolderTreeWidget::FolderTreeWidget(
     connect(d->folderTreeView, &FolderTreeView::manualSortingChanged, this, &FolderTreeWidget::slotManualSortingChanged);
 
     QVBoxLayout *lay = new QVBoxLayout(this);
-    lay->setMargin(0);
+    lay->setContentsMargins(0, 0, 0, 0);
 
     d->label = new QLabel(i18n("You can start typing to filter the list of folders."), this);
     lay->addWidget(d->label);
@@ -101,18 +99,14 @@ FolderTreeWidget::FolderTreeWidget(
               "Search"));
     lay->addWidget(d->filterFolderLineEdit);
 
-    // ... with statistics...
-    d->quotaModel = new Akonadi::QuotaColorProxyModel(this);
-    d->quotaModel->setSourceModel(KernelIf->collectionModel());
-
     if (!(options & HideStatistics)) {
         d->filterModel = new Akonadi::StatisticsProxyModel(this);
-        d->filterModel->setSourceModel(d->quotaModel);
+        d->filterModel->setSourceModel(KernelIf->collectionModel());
     }
 
     d->readableproxy = new FolderTreeWidgetProxyModel(this, optReadableProxy);
     d->readableproxy->setSourceModel((options & HideStatistics)
-                                     ? static_cast<QAbstractItemModel *>(d->quotaModel)
+                                     ? static_cast<QAbstractItemModel *>(KernelIf->collectionModel())
                                      : static_cast<QAbstractItemModel *>(d->filterModel));
     d->readableproxy->addContentMimeTypeInclusionFilter(KMime::Message::mimeType());
 
@@ -143,6 +137,7 @@ FolderTreeWidget::FolderTreeWidget(
         d->label->hide();
     } else {
         d->filterFolderLineEdit->hide();
+        setAttribute(Qt::WA_InputMethodEnabled);
     }
 }
 
@@ -271,6 +266,7 @@ void FolderTreeWidget::readConfig()
 
     d->folderTreeView->readConfig();
     d->folderTreeView->setDropActionMenuEnabled(SettingsIf->showPopupAfterDnD());
+    d->readableproxy->setWarningThreshold(SettingsIf->closeToQuotaThreshold());
     d->readableproxy->readConfig();
 
     KConfigGroup readerConfig(KernelIf->config(), "AccountOrder");
@@ -279,8 +275,6 @@ void FolderTreeWidget::readConfig()
         listOrder = readerConfig.readEntry("order", QStringList());
     }
     d->entityOrderProxy->setTopLevelOrder(listOrder);
-
-    readQuotaConfig();
 }
 
 void FolderTreeWidget::restoreHeaderState(const QByteArray &data)
@@ -310,24 +304,6 @@ void FolderTreeWidget::changeToolTipsPolicyConfig(ToolTipDisplayPolicy policy)
     d->folderTreeView->setTooltipsPolicy(policy);
 }
 
-void FolderTreeWidget::quotaWarningParameters(const QColor &color, qreal threshold)
-{
-    d->quotaModel->setWarningThreshold(threshold);
-    d->quotaModel->setWarningColor(color);
-}
-
-void FolderTreeWidget::readQuotaConfig()
-{
-    QColor quotaColor = MailCommon::Util::defaultQuotaColor();
-    qreal threshold = 100;
-    if (!MessageCore::MessageCoreSettings::self()->useDefaultColors()) {
-        KConfigGroup readerConfig(KernelIf->config(), "Reader");
-        quotaColor = readerConfig.readEntry("CloseToQuotaColor", quotaColor);
-    }
-    threshold = SettingsIf->closeToQuotaThreshold();
-    quotaWarningParameters(quotaColor, threshold);
-}
-
 Akonadi::StatisticsProxyModel *FolderTreeWidget::statisticsProxyModel() const
 {
     return d->filterModel;
@@ -419,6 +395,12 @@ bool FolderTreeWidget::eventFilter(QObject *o, QEvent *e)
             break;
         }
         }
+    } else if (e->type() == QEvent::InputMethod) {
+        const QInputMethodEvent *const ime = static_cast<QInputMethodEvent *>(e);
+        d->filter += ime->commitString();
+        applyFilter(d->filter);
+        return false;
+
     }
     return false;
 }
