@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2019 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -16,7 +16,7 @@
 */
 
 #include "searchruledatetest.h"
-#include <qtest.h>
+#include <QTest>
 #include "../searchrule/searchruledate.h"
 #include <KMime/Message>
 Q_DECLARE_METATYPE(MailCommon::SearchRule::Function)
