@@ -1,9 +1,10 @@
 /*
-  Copyright (c) 2015-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2019 Montel Laurent <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
+  This program is free software; you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 2 of the License, or
+  (at your option) any later version.
 
   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -73,14 +74,11 @@ static struct _statusNames statusNames[] = {
     }
 };
 
-static const int numStatusNames
-    = sizeof statusNames / sizeof(struct _statusNames);
-
 QString englishNameForStatus(Akonadi::MessageStatus status)
 {
-    for (int i = 0; i < numStatusNames; ++i) {
-        if (statusNames[i].status == status) {
-            return QString::fromLatin1(statusNames[i].name);
+    for (const _statusNames &statusName : statusNames) {
+        if (statusName.status == status) {
+            return QString::fromLatin1(statusName.name);
         }
     }
     return QString();
@@ -102,9 +100,9 @@ SearchRuleStatus::SearchRuleStatus(Akonadi::MessageStatus status, Function func)
 
 Akonadi::MessageStatus SearchRuleStatus::statusFromEnglishName(const QString &aStatusString)
 {
-    for (int i = 0; i < numStatusNames; ++i) {
-        if (!aStatusString.compare(QString::fromLatin1(statusNames[i].name))) {
-            return statusNames[i].status;
+    for (const _statusNames &statusName : statusNames) {
+        if (!aStatusString.compare(QString::fromLatin1(statusName.name))) {
+            return statusName.status;
         }
     }
     Akonadi::MessageStatus unknown;
@@ -164,14 +162,14 @@ void SearchRuleStatus::addQueryTerms(Akonadi::SearchTerm &groupTerm, bool &empty
     emptyIsNotAnError = true;
     //TODO double check that isRead also works
     if (!mStatus.statusFlags().isEmpty()) {
-        EmailSearchTerm term(EmailSearchTerm::MessageStatus, mStatus.statusFlags().toList().first(), akonadiComparator());
+        EmailSearchTerm term(EmailSearchTerm::MessageStatus, mStatus.statusFlags().values().first(), akonadiComparator());
         term.setIsNegated(isNegated());
         groupTerm.addSubTerm(term);
     } else {
         //Special case Unread
         Akonadi::MessageStatus status;
         status.setRead(true);
-        EmailSearchTerm term(EmailSearchTerm::MessageStatus, status.statusFlags().toList().first(), akonadiComparator());
+        EmailSearchTerm term(EmailSearchTerm::MessageStatus, status.statusFlags().values().first(), akonadiComparator());
         term.setIsNegated(!isNegated());
         groupTerm.addSubTerm(term);
     }
