@@ -2,6 +2,8 @@
   Copyright (c) 2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.com>
     Author Tobias Koenig <tokoe@kdab.com>
 
+  Copyright (c) 2019 Montel Laurent <montel@kde.org>
+
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
   the Free Software Foundation; either version 2 of the License, or (at your
@@ -28,8 +30,8 @@
 
 #include <KLocalizedString>
 #include <KMessageBox>
-#include <KConfigGroup>
 #include <QIcon>
+#include <QTextEdit>
 
 #include <QAction>
 #include <QPointer>
@@ -40,21 +42,9 @@ using namespace MailCommon;
 class Q_DECL_HIDDEN SnippetsManager::Private
 {
 public:
-    Private(SnippetsManager *qq, QWidget *parent)
+    Private(SnippetsManager *qq, QWidget *parentWidget)
         : q(qq)
-        , mModel(nullptr)
-        , mSelectionModel(nullptr)
-        , mActionCollection(nullptr)
-        , mEditor(nullptr)
-        , mAddSnippetAction(nullptr)
-        , mEditSnippetAction(nullptr)
-        , mDeleteSnippetAction(nullptr)
-        , mAddSnippetGroupAction(nullptr)
-        , mEditSnippetGroupAction(nullptr)
-        , mDeleteSnippetGroupAction(nullptr)
-        , mInsertSnippetAction(nullptr)
-        , mParent(parent)
-        , mDirty(false)
+        , mParent(parentWidget)
     {
     }
 
@@ -77,23 +67,18 @@ public:
 
     void slotAddNewDndSnippset(const QString &);
 
-    void updateActionCollection(const QString &oldName, const QString &newName, const QKeySequence &keySequence, const QString &text);
+    void updateActionCollection(const QString &oldName, const QString &newName, const QKeySequence &keySequence, const QString &text, const QString &subject, const QString &to, const QString &cc, const QString &bcc, const QString &attachment);
+    void initializeAction(const QString &newName, const QKeySequence &keySequence, const QString &text, const QString &subject, const QString &to, const QString &cc, const QString &bcc, const QString &attachment);
+    void initializeActionCollection();
 
     QString replaceVariables(const QString &text);
-    QModelIndex createGroup(const QString &groupName);
-    void createSnippet(const QModelIndex &groupIndex, const QString &snippetName, const QString &snippetText, const QString &snippetKeySequence);
 
-    void load();
     void save();
 
     SnippetsManager *q = nullptr;
     SnippetsModel *mModel = nullptr;
     QItemSelectionModel *mSelectionModel = nullptr;
     KActionCollection *mActionCollection = nullptr;
-    QObject *mEditor = nullptr;
-    QByteArray mEditorInsertMethod;
-    QMap<QString, QString> mSavedVariables;
-
     QAction *mAddSnippetAction = nullptr;
     QAction *mEditSnippetAction = nullptr;
     QAction *mDeleteSnippetAction = nullptr;
@@ -187,9 +172,16 @@ void SnippetsManager::Private::createSnippet(const QString &text)
         mModel->setData(index, dlg->name(), SnippetsModel::NameRole);
         mModel->setData(index, dlg->text(), SnippetsModel::TextRole);
         mModel->setData(index, dlg->keySequence().toString(), SnippetsModel::KeySequenceRole);
+        mModel->setData(index, dlg->keyword(), SnippetsModel::KeywordRole);
+        mModel->setData(index, dlg->subject(), SnippetsModel::SubjectRole);
+        mModel->setData(index, dlg->to(), SnippetsModel::ToRole);
+        mModel->setData(index, dlg->cc(), SnippetsModel::CcRole);
+        mModel->setData(index, dlg->bcc(), SnippetsModel::BccRole);
+        mModel->setData(index, dlg->attachment(), SnippetsModel::AttachmentRole);
 
-        updateActionCollection(QString(), dlg->name(), dlg->keySequence(), dlg->text());
+        Q_EMIT mModel->updateActionCollection(QString(), dlg->name(), dlg->keySequence(), dlg->text(), dlg->subject(), dlg->to(), dlg->cc(), dlg->bcc(), dlg->attachment());
         mDirty = true;
+        save();
     }
     delete dlg;
 }
@@ -221,6 +213,12 @@ void SnippetsManager::Private::editSnippet()
     dlg->setGroupIndex(oldGroupIndex);
     dlg->setName(oldSnippetName);
     dlg->setText(index.data(SnippetsModel::TextRole).toString());
+    dlg->setKeyword(index.data(SnippetsModel::KeywordRole).toString());
+    dlg->setSubject(index.data(SnippetsModel::SubjectRole).toString());
+    dlg->setTo(index.data(SnippetsModel::ToRole).toString());
+    dlg->setCc(index.data(SnippetsModel::CcRole).toString());
+    dlg->setBcc(index.data(SnippetsModel::BccRole).toString());
+    dlg->setAttachment(index.data(SnippetsModel::AttachmentRole).toString());
     dlg->setKeySequence(
         QKeySequence::fromString(
             index.data(SnippetsModel::KeySequenceRole).toString()));
@@ -238,9 +236,16 @@ void SnippetsManager::Private::editSnippet()
         mModel->setData(index, dlg->name(), SnippetsModel::NameRole);
         mModel->setData(index, dlg->text(), SnippetsModel::TextRole);
         mModel->setData(index, dlg->keySequence().toString(), SnippetsModel::KeySequenceRole);
+        mModel->setData(index, dlg->keyword(), SnippetsModel::KeywordRole);
+        mModel->setData(index, dlg->subject(), SnippetsModel::SubjectRole);
+        mModel->setData(index, dlg->to(), SnippetsModel::ToRole);
+        mModel->setData(index, dlg->cc(), SnippetsModel::CcRole);
+        mModel->setData(index, dlg->bcc(), SnippetsModel::BccRole);
+        mModel->setData(index, dlg->attachment(), SnippetsModel::AttachmentRole);
 
-        updateActionCollection(oldSnippetName, dlg->name(), dlg->keySequence(), dlg->text());
+        Q_EMIT mModel->updateActionCollection(oldSnippetName, dlg->name(), dlg->keySequence(), dlg->text(), dlg->subject(), dlg->to(), dlg->cc(), dlg->bcc(), dlg->attachment());
         mDirty = true;
+        save();
     }
     delete dlg;
 }
@@ -263,8 +268,9 @@ void SnippetsManager::Private::deleteSnippet()
 
     mModel->removeRow(index.row(), currentGroupIndex());
 
-    updateActionCollection(snippetName, QString(), QKeySequence(), QString());
+    Q_EMIT mModel->updateActionCollection(snippetName, QString(), QKeySequence(), QString(), QString(), QString(), QString(), QString(), QString());
     mDirty = true;
+    save();
 }
 
 void SnippetsManager::Private::addSnippetGroup()
@@ -282,6 +288,7 @@ void SnippetsManager::Private::addSnippetGroup()
         const QModelIndex groupIndex = mModel->index(mModel->rowCount() - 1, 0, QModelIndex());
         mModel->setData(groupIndex, dlg->name(), SnippetsModel::NameRole);
         mDirty = true;
+        save();
     }
     delete dlg;
 }
@@ -306,6 +313,7 @@ void SnippetsManager::Private::editSnippetGroup()
 
         mModel->setData(groupIndex, dlg->name(), SnippetsModel::NameRole);
         mDirty = true;
+        save();
     }
     delete dlg;
 }
@@ -342,14 +350,11 @@ void SnippetsManager::Private::deleteSnippetGroup()
 
     mModel->removeRow(groupIndex.row(), QModelIndex());
     mDirty = true;
+    save();
 }
 
 void SnippetsManager::Private::insertSelectedSnippet()
 {
-    if (!mEditor) {
-        return;
-    }
-
     if (!mSelectionModel->hasSelection()) {
         return;
     }
@@ -360,30 +365,64 @@ void SnippetsManager::Private::insertSelectedSnippet()
     }
 
     const QString text = replaceVariables(index.data(SnippetsModel::TextRole).toString());
-    QMetaObject::invokeMethod(mEditor, mEditorInsertMethod.constData(), Qt::DirectConnection,
-                              Q_ARG(QString, text));
+    const QString subject = replaceVariables(index.data(SnippetsModel::SubjectRole).toString());
+    const QString to = index.data(SnippetsModel::ToRole).toString();
+    const QString cc = index.data(SnippetsModel::CcRole).toString();
+    const QString bcc = index.data(SnippetsModel::BccRole).toString();
+    const QString attachment = index.data(SnippetsModel::AttachmentRole).toString();
+    Q_EMIT q->insertSnippetInfo({subject, text, to, cc, bcc, attachment});
 }
 
 void SnippetsManager::Private::insertActionSnippet()
 {
-    if (!mEditor) {
-        return;
-    }
-
     QAction *action = qobject_cast<QAction *>(q->sender());
     if (!action) {
         return;
     }
 
     const QString text = replaceVariables(action->property("snippetText").toString());
-    QMetaObject::invokeMethod(mEditor, mEditorInsertMethod.constData(), Qt::DirectConnection,
-                              Q_ARG(QString, text));
+    const QString subject = replaceVariables(action->property("snippetSubject").toString());
+    const QString to = action->property("snippetTo").toString();
+    const QString cc = action->property("snippetCc").toString();
+    const QString bcc = action->property("snippetBcc").toString();
+    const QString attachment = action->property("snippetAttachment").toString();
+    Q_EMIT q->insertSnippetInfo({subject, text, to, cc, bcc, attachment});
 }
 
-void SnippetsManager::Private::updateActionCollection(const QString &oldName, const QString &newName, const QKeySequence &keySequence, const QString &text)
+void SnippetsManager::Private::initializeActionCollection()
+{
+    if (mActionCollection) {
+        const QVector<SnippetsInfo> infos = mModel->snippetsInfo();
+        for (const SnippetsInfo &info : infos) {
+            initializeAction(info.newName, info.keySequence, info.text, info.subject, info.to, info.cc, info.bcc, info.attachment);
+        }
+    }
+}
+
+void SnippetsManager::Private::initializeAction(const QString &newName, const QKeySequence &keySequence, const QString &text, const QString &subject, const QString &to, const QString &cc, const QString &bcc, const QString &attachment)
+{
+    const QString actionName = i18nc("@action", "Snippet %1", newName);
+    const QString normalizedName = QString(actionName).replace(QLatin1Char(' '), QLatin1Char('_'));
+
+    QAction *action
+        = mActionCollection->addAction(normalizedName, q);
+    connect(action, &QAction::triggered, q, [this]() {
+        insertActionSnippet();
+    });
+    action->setProperty("snippetText", text);
+    action->setProperty("snippetSubject", subject);
+    action->setProperty("snippetTo", to);
+    action->setProperty("snippetCc", cc);
+    action->setProperty("snippetBcc", bcc);
+    action->setProperty("snippetAttachment", attachment);
+    action->setText(actionName);
+    mActionCollection->setDefaultShortcut(action, keySequence);
+}
+
+void SnippetsManager::Private::updateActionCollection(const QString &oldName, const QString &newName, const QKeySequence &keySequence, const QString &text, const QString &subject, const QString &to, const QString &cc, const QString &bcc, const QString &attachment)
 {
     // remove previous action in case that the name changed
-    if (!oldName.isEmpty()) {
+    if (!oldName.isEmpty() && mActionCollection) {
         const QString actionName = i18nc("@action", "Snippet %1", oldName);
         const QString normalizedName = QString(actionName).replace(QLatin1Char(' '), QLatin1Char('_'));
 
@@ -394,17 +433,7 @@ void SnippetsManager::Private::updateActionCollection(const QString &oldName, co
     }
 
     if (!newName.isEmpty()) {
-        const QString actionName = i18nc("@action", "Snippet %1", newName);
-        const QString normalizedName = QString(actionName).replace(QLatin1Char(' '), QLatin1Char('_'));
-
-        QAction *action
-            = mActionCollection->addAction(normalizedName, q);
-        connect(action, &QAction::triggered, q, [this]() {
-            insertActionSnippet();
-        });
-        action->setProperty("snippetText", text);
-        action->setText(actionName);
-        mActionCollection->setDefaultShortcut(action, keySequence);
+        initializeAction(newName, keySequence, text, subject, to, cc, bcc, attachment);
     }
 }
 
@@ -413,10 +442,10 @@ QString SnippetsManager::Private::replaceVariables(const QString &text)
     QString result = text;
     QString variableName;
     QString variableValue;
-    QMap<QString, QString> localVariables(mSavedVariables);
+    QMap<QString, QString> localVariables(SnippetsModel::instance()->savedVariables());
     int iFound = -1;
     int iEnd = -1;
-
+    QMap<QString, QString> tempLocalVariables(localVariables);
     do {
         //find the next variable by this QRegExp
         iFound = text.indexOf(QRegExp(QLatin1String("\\$[A-Za-z-_0-9\\s]*\\$")), iEnd + 1);
@@ -427,7 +456,7 @@ QString SnippetsManager::Private::replaceVariables(const QString &text)
 
             if (variableName != QLatin1String("$$")) {      // if not double-delimiter
                 if (!localVariables.contains(variableName)) {      // and not already in map
-                    QPointer<SnippetVariableDialog> dlg = new SnippetVariableDialog(variableName, &mSavedVariables, mParent);
+                    QPointer<SnippetVariableDialog> dlg = new SnippetVariableDialog(variableName, &tempLocalVariables, mParent);
                     if (dlg->exec()) {
                         if (dlg->saveVariableIsChecked()) {
                             mDirty = true;
@@ -449,171 +478,48 @@ QString SnippetsManager::Private::replaceVariables(const QString &text)
             localVariables[ variableName ] = variableValue;
         }
     } while (iFound != -1);
+    SnippetsModel::instance()->setSavedVariables(tempLocalVariables);
 
     return result;
 }
 
-QModelIndex SnippetsManager::Private::createGroup(const QString &groupName)
-{
-    mModel->insertRow(mModel->rowCount(), QModelIndex());
-    const QModelIndex groupIndex = mModel->index(mModel->rowCount() - 1, 0, QModelIndex());
-    mModel->setData(groupIndex, groupName, SnippetsModel::NameRole);
-    return groupIndex;
-}
-
-void SnippetsManager::Private::createSnippet(const QModelIndex &groupIndex, const QString &snippetName, const QString &snippetText, const QString &snippetKeySequence)
-{
-    mModel->insertRow(mModel->rowCount(groupIndex), groupIndex);
-    const QModelIndex index = mModel->index(mModel->rowCount(groupIndex) - 1, 0, groupIndex);
-
-    mModel->setData(index, snippetName, SnippetsModel::NameRole);
-    mModel->setData(index, snippetText, SnippetsModel::TextRole);
-    mModel->setData(index, snippetKeySequence, SnippetsModel::KeySequenceRole);
-
-    updateActionCollection(QString(),
-                           snippetName,
-                           QKeySequence::fromString(snippetKeySequence),
-                           snippetText);
-}
-
-void SnippetsManager::Private::load()
-{
-    const KSharedConfig::Ptr config
-        = KSharedConfig::openConfig(QStringLiteral("kmailsnippetrc"), KConfig::NoGlobals);
-
-    const KConfigGroup snippetPartGroup = config->group("SnippetPart");
-
-    const int groupCount = snippetPartGroup.readEntry("snippetGroupCount", 0);
-
-    for (int i = 0; i < groupCount; ++i) {
-        const KConfigGroup group
-            = config->group(QStringLiteral("SnippetGroup_%1").arg(i));
-
-        const QString groupName = group.readEntry("Name");
-
-        // create group
-        QModelIndex groupIndex = createGroup(groupName);
-
-        const int snippetCount = group.readEntry("snippetCount", 0);
-        for (int j = 0; j < snippetCount; ++j) {
-            const QString snippetName
-                = group.readEntry(QStringLiteral("snippetName_%1").arg(j), QString());
-
-            const QString snippetText
-                = group.readEntry(QStringLiteral("snippetText_%1").arg(j), QString());
-
-            const QString snippetKeySequence
-                = group.readEntry(QStringLiteral("snippetKeySequence_%1").arg(j), QString());
-
-            createSnippet(groupIndex, snippetName, snippetText, snippetKeySequence);
-        }
-    }
-
-    mSavedVariables.clear();
-    const KConfigGroup group = config->group("SavedVariablesPart");
-    const int variablesCount = group.readEntry("variablesCount", 0);
-
-    for (int i = 0; i < variablesCount; ++i) {
-        const QString variableKey
-            = group.readEntry(QStringLiteral("variableName_%1").arg(i), QString());
-
-        const QString variableValue
-            = group.readEntry(QStringLiteral("variableValue_%1").arg(i), QString());
-
-        mSavedVariables.insert(variableKey, variableValue);
-    }
-}
-
 void SnippetsManager::Private::save()
 {
     if (!mDirty) {
         return;
     }
 
-    KSharedConfig::Ptr config = KSharedConfig::openConfig(QStringLiteral("kmailsnippetrc"), KConfig::NoGlobals);
-
-    // clear everything
-    for (const QString &group : config->groupList()) {
-        config->deleteGroup(group);
-    }
-
-    // write number of snippet groups
-    KConfigGroup group = config->group("SnippetPart");
-
-    const int groupCount = mModel->rowCount();
-    group.writeEntry("snippetGroupCount", groupCount);
-
-    for (int i = 0; i < groupCount; ++i) {
-        const QModelIndex groupIndex = mModel->index(i, 0, QModelIndex());
-        const QString groupName = groupIndex.data(SnippetsModel::NameRole).toString();
-
-        KConfigGroup group = config->group(QStringLiteral("SnippetGroup_%1").arg(i));
-        group.writeEntry("Name", groupName);
-
-        const int snippetCount = mModel->rowCount(groupIndex);
-
-        group.writeEntry("snippetCount", snippetCount);
-        for (int j = 0; j < snippetCount; ++j) {
-            const QModelIndex index = mModel->index(j, 0, groupIndex);
-
-            const QString snippetName = index.data(SnippetsModel::NameRole).toString();
-            if (!snippetName.isEmpty()) {
-                const QString snippetText = index.data(SnippetsModel::TextRole).toString();
-                const QString snippetKeySequence = index.data(SnippetsModel::KeySequenceRole).toString();
-
-                group.writeEntry(QStringLiteral("snippetName_%1").arg(j), snippetName);
-                if (!snippetText.isEmpty()) {
-                    group.writeEntry(QStringLiteral("snippetText_%1").arg(j), snippetText);
-                }
-                if (!snippetKeySequence.isEmpty()) {
-                    group.writeEntry(QStringLiteral("snippetKeySequence_%1").arg(j),
-                                     snippetKeySequence);
-                }
-            }
-        }
-    }
-
-    {
-        KConfigGroup group = config->group("SavedVariablesPart");
-
-        const int variablesCount = mSavedVariables.count();
-        group.writeEntry("variablesCount", variablesCount);
-
-        int counter = 0;
-        QMap<QString, QString>::const_iterator it = mSavedVariables.cbegin();
-        const QMap<QString, QString>::const_iterator itEnd = mSavedVariables.cend();
-        for (; it != itEnd; ++it) {
-            group.writeEntry(QStringLiteral("variableName_%1").arg(counter), it.key());
-            group.writeEntry(QStringLiteral("variableValue_%1").arg(counter), it.value());
-            counter++;
-        }
-    }
-
-    config->sync();
+    SnippetsModel::instance()->save();
     mDirty = false;
 }
 
-SnippetsManager::SnippetsManager(KActionCollection *actionCollection, QObject *parent, QWidget *widget)
+SnippetsManager::SnippetsManager(KActionCollection *actionCollection, QObject *parent, QWidget *parentWidget)
     : QObject(parent)
-    , d(new Private(this, widget))
+    , d(new Private(this, parentWidget))
 {
-    d->mModel = new SnippetsModel(this);
+    d->mModel = SnippetsModel::instance();
+    connect(d->mModel, &SnippetsModel::updateActionCollection, this, [this](const QString &oldName, const QString &newName, const QKeySequence &keySequence, const QString &text, const QString &subject, const QString &to, const QString &cc, const QString &bcc, const QString &attachment) {
+        d->updateActionCollection(oldName, newName, keySequence, text, subject, to, cc, bcc, attachment);
+    });
     d->mSelectionModel = new QItemSelectionModel(d->mModel);
     d->mActionCollection = actionCollection;
 
     d->mAddSnippetAction = new QAction(i18n("Add Snippet..."), this);
+    d->mAddSnippetAction->setIcon(QIcon::fromTheme(QStringLiteral("list-add")));
     d->mEditSnippetAction = new QAction(i18n("Edit Snippet..."), this);
     d->mEditSnippetAction->setIcon(QIcon::fromTheme(QStringLiteral("document-properties")));
     d->mDeleteSnippetAction = new QAction(i18n("Remove Snippet"), this);
     d->mDeleteSnippetAction->setIcon(QIcon::fromTheme(QStringLiteral("edit-delete")));
 
     d->mAddSnippetGroupAction = new QAction(i18n("Add Group..."), this);
+    d->mAddSnippetGroupAction->setIcon(QIcon::fromTheme(QStringLiteral("list-add")));
     d->mEditSnippetGroupAction = new QAction(i18n("Rename Group..."), this);
     d->mEditSnippetGroupAction->setIcon(QIcon::fromTheme(QStringLiteral("edit-rename")));
     d->mDeleteSnippetGroupAction = new QAction(i18n("Remove Group"), this);
     d->mDeleteSnippetGroupAction->setIcon(QIcon::fromTheme(QStringLiteral("edit-delete")));
 
     d->mInsertSnippetAction = new QAction(i18n("Insert Snippet"), this);
+    d->mInsertSnippetAction->setIcon(QIcon::fromTheme(QStringLiteral("insert-text")));
 
     connect(d->mSelectionModel, &QItemSelectionModel::selectionChanged,
             this, [this]() {
@@ -650,9 +556,11 @@ SnippetsManager::SnippetsManager(KActionCollection *actionCollection, QObject *p
         d->insertSelectedSnippet();
     });
 
+    d->initializeActionCollection();
     d->selectionChanged();
-
-    d->load();
+    connect(this, &SnippetsManager::insertSnippet, this, [this]() {
+        d->insertSelectedSnippet();
+    });
 }
 
 SnippetsManager::~SnippetsManager()
@@ -661,21 +569,6 @@ SnippetsManager::~SnippetsManager()
     delete d;
 }
 
-void SnippetsManager::setEditor(QObject *editor, const char *insertSnippetMethod, const char *dropSignal)
-{
-    d->mEditor = editor;
-    d->mEditorInsertMethod = insertSnippetMethod;
-
-    if (dropSignal) {
-        const int index
-            = editor->metaObject()->indexOfSignal(
-            QMetaObject::normalizedSignature(dropSignal + 1).data());        // skip the leading '2'
-        if (index != -1) {
-            connect(editor, dropSignal, this, SLOT(insertSelectedSnippet()));
-        }
-    }
-}
-
 QAbstractItemModel *SnippetsManager::model() const
 {
     return d->mModel;
