@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2012-2018 Montel Laurent <montel@kde.org>
+  Copyright (c) 2012-2019 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -71,7 +71,7 @@ TagWidget::TagWidget(const QList<KActionCollection *> &actionCollections, QWidge
     , d(new MailCommon::TagWidgetPrivate)
 {
     QGridLayout *settings = new QGridLayout(this);
-    settings->setMargin(0);
+    settings->setContentsMargins(0, 0, 0, 0);
 
     //Stretcher layout for adding some space after the label
     QVBoxLayout *spacer = new QVBoxLayout();
