@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2019 Montel Laurent <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -23,32 +23,27 @@
 
 #include <QWidget>
 
-namespace MessageComposer
-{
+namespace MessageComposer {
 class ComposerLineEdit;
 }
 
-namespace MailCommon
-{
-
+namespace MailCommon {
 class RedirectWidget : public QWidget
 {
     Q_OBJECT
 public:
-    explicit RedirectWidget(QWidget *parent = Q_NULLPTR);
+    explicit RedirectWidget(QWidget *parent = nullptr);
     ~RedirectWidget();
 
     void setFocus();
-    QString resend();
+    Q_REQUIRED_RESULT QString resend();
 
 Q_SIGNALS:
     void addressChanged(const QString &);
 
-private Q_SLOTS:
-    void slotAddressSelection();
-
 private:
-    MessageComposer::ComposerLineEdit *mEdit;
+    void slotAddressSelection();
+    MessageComposer::ComposerLineEdit *mEdit = nullptr;
     QString mResendStr;
 };
 }
